# -*- coding: utf-8 -*-
from selenium.common.exceptions import WebDriverException


class WebDriverModuleException(WebDriverException):
    pass


class WebDriverOverMaxAttempts(WebDriverModuleException):
    """
    Количество попыток получить страницу исчерпано
    """
    message = 'WebDriverOverMaxAttempts exception'


class WebDriverNoSuchElement(WebDriverModuleException):
    """
    Не смог найти элемент на странице по айди, классу или xpath
    """
    message = 'WebDriverNoSuchElement exception'


class WebDriverConnectionError(WebDriverModuleException):
    """
    Что-то с коннектом
    """
    message = 'WebDriverConnectionExcetion exception'


class WebDriverAnotherException(WebDriverModuleException):
    """
    При таком exception надо ставить save_logs_locally true и смотреть selenium.log
    """
    message = 'WebDriverAnotherException exception'


class WebDriverAuthIsBrokenException(WebDriverModuleException):
    """
    Не удалось с полученными селекторами залогиниться на платформе
    """
    message = 'WebDriverAuthIsBrokenException exception'


class WebDriverPageIsNotReceived(WebDriverModuleException):
    """
    Не смогли получить страницу
    """
    message = 'WebDriverPageIsNotRecieved exception'



from setuptools import setup

setup(
    name='Chromoy',  # This is the name of your PyPI-package.
    author="Alexey Savchenko",
    author_email="beastrock@mail.ru",
    url="https://github.com/Beastrock/Chromoy",
    description="Refreshed chrome-driver for parsing and cron-testing.",
    version='0.02',  # Update the version number for new releases,
    packages=['chromoy'],
    install_requires=[
        'selenium==3.14.0',
        'beautifulsoup4==4.6.3',
        'lxml==4.2.4',
        'PyVirtualDisplay==0.2.1',
        'requests==2.19.1',
        'psutil==5.4.7',
    ],
)
